@@ -27,7 +27,6 @@
 #include <gtk/gtk.h>
 #include <gdk/gdkx.h>
 
-#include "clocks_banner.h"
 #include "ctkimage.h"
 
 #include "ctkclocks.h"
@@ -293,11 +292,13 @@ GtkWidget* ctk_clocks_new(NvCtrlAttributeHandle *handle,
     int value;
     int clocks_2D;
     NVCTRLAttributeValidValuesRec ranges_2D;
+    NVCTRLAttributeValidValuesRec range_detection;
     int clocks_3D;
     NVCTRLAttributeValidValuesRec ranges_3D;
 
     Bool overclocking_enabled;
-    Bool probing_optimal;
+    Bool auto_detection_available = FALSE;
+    Bool probing_optimal = FALSE;
     Bool can_access_2d_clocks;
     Bool can_access_3d_clocks;
    
@@ -318,14 +319,19 @@ GtkWidget* ctk_clocks_new(NvCtrlAttributeHandle *handle,
     /* Check if overclocking is busy */
     
     if ( overclocking_enabled ) {
-        ret = NvCtrlGetAttribute(handle,
-                                 NV_CTRL_GPU_OPTIMAL_CLOCK_FREQS_DETECTION_STATE,
-                                 &value);
-        if ( ret != NvCtrlSuccess )
-            return NULL;
-        probing_optimal = (value==NV_CTRL_GPU_OPTIMAL_CLOCK_FREQS_DETECTION_STATE_BUSY);
-    } else {
-        probing_optimal = FALSE;
+        ret = NvCtrlGetValidAttributeValues(handle,
+                                 NV_CTRL_GPU_OPTIMAL_CLOCK_FREQS_DETECTION,
+                                 &range_detection);
+        if ( ret == NvCtrlSuccess ) {
+            ret = NvCtrlGetAttribute(handle,
+                                     NV_CTRL_GPU_OPTIMAL_CLOCK_FREQS_DETECTION_STATE,
+                                     &value);
+            if ( ret != NvCtrlSuccess )
+                return NULL;
+            probing_optimal =
+                (value == NV_CTRL_GPU_OPTIMAL_CLOCK_FREQS_DETECTION_STATE_BUSY);
+            auto_detection_available = TRUE;
+        }
     }
 
     /* Can we access the 2D clocks? */
@@ -366,6 +372,7 @@ GtkWidget* ctk_clocks_new(NvCtrlAttributeHandle *handle,
     ctk_object->ctk_config           = ctk_config;
     ctk_object->license_accepted     = // = overclocking_enabled
     ctk_object->overclocking_enabled = overclocking_enabled;
+    ctk_object->auto_detection_available  = auto_detection_available;
     ctk_object->probing_optimal      = probing_optimal;
 
     /* Create the Clock menu widget */
@@ -511,7 +518,8 @@ GtkWidget* ctk_clocks_new(NvCtrlAttributeHandle *handle,
         gtk_widget_set_sensitive(ctk_object->detect_button, False);
     } else {
         gtk_widget_set_sensitive(ctk_object->detect_button,
-                                 overclocking_enabled && !probing_optimal);
+                                 overclocking_enabled &&
+                                 auto_detection_available && !probing_optimal);
     }
 
     /* Create the Reset hardware button widget */
@@ -618,7 +626,7 @@ GtkWidget* ctk_clocks_new(NvCtrlAttributeHandle *handle,
 
     gtk_box_set_spacing(GTK_BOX(ctk_object), 10);
 
-    banner = ctk_banner_image_new(&clocks_banner_image);
+    banner = ctk_banner_image_new(BANNER_ARTWORK_CLOCK);
     gtk_box_pack_start(GTK_BOX(object), banner, FALSE, FALSE, 0);
 
     /* Add Overclocking checkbox */
@@ -688,11 +696,6 @@ GtkWidget* ctk_clocks_new(NvCtrlAttributeHandle *handle,
                      G_CALLBACK(clocks_received),
                      (gpointer) ctk_object);
     
-    g_signal_connect(G_OBJECT(ctk_event),
-                     CTK_EVENT_NAME(NV_CTRL_GPU_OPTIMAL_CLOCK_FREQS),
-                     G_CALLBACK(clocks_received),
-                     (gpointer) ctk_object);
-    
     g_signal_connect(G_OBJECT(ctk_event),
                      CTK_EVENT_NAME(NV_CTRL_GPU_OPTIMAL_CLOCK_FREQS),
                      G_CALLBACK(clocks_received),
@@ -833,9 +836,12 @@ static void sync_gui_sensitivity(CtkClocks *ctk_object)
                                __cancel_button_help);
 
     } else {
+        gboolean set_sensitive;
         gtk_button_set_label(GTK_BUTTON(ctk_object->detect_button), "Auto Detect");
-        gtk_widget_set_sensitive(ctk_object->detect_button, 
-                                 (ctk_object->clocks_being_modified == CLOCKS_3D)?enabled:False);
+        set_sensitive = ((ctk_object->auto_detection_available) &&
+                         (ctk_object->clocks_being_modified == CLOCKS_3D))
+                        ? enabled : False;
+        gtk_widget_set_sensitive(ctk_object->detect_button, set_sensitive);
         ctk_config_set_tooltip(ctk_object->ctk_config, ctk_object->detect_button,
                                __detect_button_help);
     }
@@ -1150,6 +1156,10 @@ static void sync_gui_to_modify_clocks(CtkClocks *ctk_object, int which_clocks)
                         GET_GPU_CLOCK(clk_ranges.u.range.min),
                         GET_GPU_CLOCK(clk_ranges.u.range.max));
 
+    g_signal_handlers_unblock_by_func(G_OBJECT(gtk_adjustment_gpu),
+                                      G_CALLBACK(adjustment_value_changed),
+                                      (gpointer) ctk_object);
+
     gtk_range = GTK_RANGE(CTK_SCALE(ctk_object->mem_clk_scale)->gtk_scale);
     gtk_adjustment_mem = GTK_ADJUSTMENT(gtk_range->adjustment);
 
@@ -1166,11 +1176,6 @@ static void sync_gui_to_modify_clocks(CtkClocks *ctk_object, int which_clocks)
                                       G_CALLBACK(adjustment_value_changed),
                                       (gpointer) ctk_object);
 
-    g_signal_handlers_unblock_by_func(G_OBJECT(gtk_adjustment_gpu),
-                                      G_CALLBACK(adjustment_value_changed),
-                                      (gpointer) ctk_object);
-
-
     /* Update the gui sensitivity */
     
     sync_gui_sensitivity(ctk_object);
